# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/resolver/resolver.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/resolver/resolver.proto\x12\x0f\x65olymp.resolver\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\"\x84\x03\n\x06Record\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x10\n\x08space_id\x18\x02 \x01(\t\x12\x0f\n\x07summary\x18\x03 \x01(\t\x12*\n\x04\x61uth\x18\n \x01(\x0b\x32\x1c.eolymp.resolver.Record.Auth\x12.\n\x06target\x18\x14 \x01(\x0b\x32\x1e.eolymp.resolver.Record.Target\x1aj\n\x04\x41uth\x12\x11\n\tclient_id\x18\n \x01(\t\x12\x15\n\rclient_secret\x18\x0b \x01(\t\x12\x0e\n\x06scopes\x18\x0c \x01(\t\x12\x11\n\ttoken_url\x18\x14 \x01(\t\x12\x15\n\rauthorize_url\x18\x1e \x01(\t\x1a\x41\n\x06Target\x12*\n\x04type\x18\x01 \x01(\x0e\x32\x1c.eolymp.resolver.Record.Type\x12\x0b\n\x03url\x18\x02 \x01(\t\"?\n\x04Type\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\t\n\x05SPACE\x10\x01\x12\x0b\n\x07\x43ONTEST\x10\x02\x12\x0e\n\nSCOREBOARD\x10\x03\" \n\x10ResolveNameInput\x12\x0c\n\x04name\x18\x01 \x01(\t\"o\n\x11ResolveNameOutput\x12*\n\x04\x61uth\x18\x01 \x01(\x0b\x32\x1c.eolymp.resolver.Record.Auth\x12.\n\x06target\x18\x02 \x01(\x0b\x32\x1e.eolymp.resolver.Record.Target2\x86\x01\n\x08Resolver\x12z\n\x0bResolveName\x12!.eolymp.resolver.ResolveNameInput\x1a\".eolymp.resolver.ResolveNameOutput\"$\xea\xe2\n\x0b\xf5\xe2\n\x00\x00HB\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0f\x12\r/names/{name}B3Z1github.com/eolymp/go-sdk/eolymp/resolver;resolverb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.resolver.resolver_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/resolver;resolver'
  _RESOLVER.methods_by_name['ResolveName']._options = None
  _RESOLVER.methods_by_name['ResolveName']._serialized_options = b'\352\342\n\013\365\342\n\000\000HB\370\342\nd\202\323\344\223\002\017\022\r/names/{name}'
  _RECORD._serialized_start=151
  _RECORD._serialized_end=539
  _RECORD_AUTH._serialized_start=301
  _RECORD_AUTH._serialized_end=407
  _RECORD_TARGET._serialized_start=409
  _RECORD_TARGET._serialized_end=474
  _RECORD_TYPE._serialized_start=476
  _RECORD_TYPE._serialized_end=539
  _RESOLVENAMEINPUT._serialized_start=541
  _RESOLVENAMEINPUT._serialized_end=573
  _RESOLVENAMEOUTPUT._serialized_start=575
  _RESOLVENAMEOUTPUT._serialized_end=686
  _RESOLVER._serialized_start=689
  _RESOLVER._serialized_end=823
# @@protoc_insertion_point(module_scope)
