# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/cognito/user.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x65olymp/cognito/user.proto\x12\x0e\x65olymp.cognito\x1a\x1fgoogle/protobuf/timestamp.proto\"\x91\x04\n\x04User\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12\x0c\n\x04rank\x18) \x01(\r\x12\x32\n\nrank_trend\x18* \x01(\x0e\x32\x1e.eolymp.cognito.User.RankTrend\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0f\n\x07picture\x18\x0b \x01(\t\x12\x0f\n\x07\x63ompany\x18\x0c \x01(\t\x12\x12\n\noccupation\x18\r \x01(\t\x12\x0f\n\x07\x63ountry\x18\x15 \x01(\t\x12\x0c\n\x04\x63ity\x18\x16 \x01(\t\x12\x14\n\x0c\x65mail_status\x18  \x01(\t\x12\x10\n\x08\x62irthday\x18! \x01(\t\x12\x31\n\rregistered_on\x18\" \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rlast_activity\x18# \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x13username_changed_on\x18$ \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x13password_changed_on\x18% \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\'\n\tRankTrend\x12\x08\n\x04NONE\x10\x00\x12\x06\n\x02UP\x10\x01\x12\x08\n\x04\x44OWN\x10\x02\x42\x31Z/github.com/eolymp/go-sdk/eolymp/cognito;cognitob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.cognito.user_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/cognito;cognito'
  _USER._serialized_start=79
  _USER._serialized_end=608
  _USER_RANKTREND._serialized_start=569
  _USER_RANKTREND._serialized_end=608
# @@protoc_insertion_point(module_scope)
