# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/ranker/ranker.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.annotations import service_pb2 as eolymp_dot_annotations_dot_service__pb2
from eolymp.ranker import activity_pb2 as eolymp_dot_ranker_dot_activity__pb2
from eolymp.ranker import scoreboard_pb2 as eolymp_dot_ranker_dot_scoreboard__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/ranker/ranker.proto\x12\reolymp.ranker\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a eolymp/annotations/service.proto\x1a\x1c\x65olymp/ranker/activity.proto\x1a\x1e\x65olymp/ranker/scoreboard.proto\x1a!eolymp/wellknown/expression.proto\"F\n\x15\x43reateScoreboardInput\x12-\n\nscoreboard\x18\x01 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"/\n\x16\x43reateScoreboardOutput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"]\n\x15UpdateScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12-\n\nscoreboard\x18\x02 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"\x18\n\x16UpdateScoreboardOutput\"/\n\x16RebuildScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\".\n\x17RebuildScoreboardOutput\x12\x13\n\x0b\x61\x63tivity_id\x18\x01 \x01(\t\".\n\x15\x44\x65leteScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteScoreboardOutput\"H\n\x17\x44\x65scribeScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x16\n\x0escoreboard_key\x18\x02 \x01(\t\"I\n\x18\x44\x65scribeScoreboardOutput\x12-\n\nscoreboard\x18\x01 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"\xa7\x01\n\x14ListScoreboardsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.ranker.ListScoreboardsInput.Filter\x1a\x34\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"P\n\x15ListScoreboardsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.ranker.Scoreboard\"F\n\x1a\x44\x65scribeScoreboardRowInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\"I\n\x1b\x44\x65scribeScoreboardRowOutput\x12*\n\x03row\x18\x01 \x01(\x0b\x32\x1d.eolymp.ranker.Scoreboard.Row\"\xcb\x01\n\x17ListScoreboardRowsInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12>\n\x07\x66ilters\x18( \x01(\x0b\x32-.eolymp.ranker.ListScoreboardRowsInput.Filter\x1a;\n\x06\x46ilter\x12\x31\n\tmember_id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"W\n\x18ListScoreboardRowsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12,\n\x05items\x18\x02 \x03(\x0b\x32\x1d.eolymp.ranker.Scoreboard.Row\"c\n\x18\x41\x64\x64ScoreboardColumnInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x30\n\x06\x63olumn\x18\x02 \x01(\x0b\x32 .eolymp.ranker.Scoreboard.Column\".\n\x19\x41\x64\x64ScoreboardColumnOutput\x12\x11\n\tcolumn_id\x18\x01 \x01(\t\"G\n\x1b\x44\x65leteScoreboardColumnInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x11\n\tcolumn_id\x18\x02 \x01(\t\"\x1e\n\x1c\x44\x65leteScoreboardColumnOutput\"I\n\x1d\x44\x65scribeScoreboardColumnInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x11\n\tcolumn_id\x18\x02 \x01(\t\"R\n\x1e\x44\x65scribeScoreboardColumnOutput\x12\x30\n\x06\x63olumn\x18\x01 \x01(\x0b\x32 .eolymp.ranker.Scoreboard.Column\"3\n\x1aListScoreboardColumnsInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"]\n\x1bListScoreboardColumnsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12/\n\x05items\x18\x02 \x03(\x0b\x32 .eolymp.ranker.Scoreboard.Column\"J\n\x13ListActivitiesInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"M\n\x14ListActivitiesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.ranker.Activity2\xdb\x13\n\x06Ranker\x12\xa3\x01\n\x10\x43reateScoreboard\x12$.eolymp.ranker.CreateScoreboardInput\x1a%.eolymp.ranker.CreateScoreboardOutput\"B\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0e\"\x0c/scoreboards\x12\xb3\x01\n\x10UpdateScoreboard\x12$.eolymp.ranker.UpdateScoreboardInput\x1a%.eolymp.ranker.UpdateScoreboardOutput\"R\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e\x1a\x1c/scoreboards/{scoreboard_id}\x12\xbe\x01\n\x11RebuildScoreboard\x12%.eolymp.ranker.RebuildScoreboardInput\x1a&.eolymp.ranker.RebuildScoreboardOutput\"Z\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02&\"$/scoreboards/{scoreboard_id}/rebuild\x12\xb3\x01\n\x10\x44\x65leteScoreboard\x12$.eolymp.ranker.DeleteScoreboardInput\x1a%.eolymp.ranker.DeleteScoreboardOutput\"R\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x1e*\x1c/scoreboards/{scoreboard_id}\x12\xb8\x01\n\x12\x44\x65scribeScoreboard\x12&.eolymp.ranker.DescribeScoreboardInput\x1a\'.eolymp.ranker.DescribeScoreboardOutput\"Q\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1e\x12\x1c/scoreboards/{scoreboard_id}\x12\x9f\x01\n\x0fListScoreboards\x12#.eolymp.ranker.ListScoreboardsInput\x1a$.eolymp.ranker.ListScoreboardsOutput\"A\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/scoreboards\x12\xd2\x01\n\x15\x44\x65scribeScoreboardRow\x12).eolymp.ranker.DescribeScoreboardRowInput\x1a*.eolymp.ranker.DescribeScoreboardRowOutput\"b\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02/\x12-/scoreboards/{scoreboard_id}/rows/{member_id}\x12\xbd\x01\n\x12ListScoreboardRows\x12&.eolymp.ranker.ListScoreboardRowsInput\x1a\'.eolymp.ranker.ListScoreboardRowsOutput\"V\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02#\x12!/scoreboards/{scoreboard_id}/rows\x12\xc4\x01\n\x13\x41\x64\x64ScoreboardColumn\x12\'.eolymp.ranker.AddScoreboardColumnInput\x1a(.eolymp.ranker.AddScoreboardColumnOutput\"Z\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02&\"$/scoreboards/{scoreboard_id}/columns\x12\xd9\x01\n\x16\x44\x65leteScoreboardColumn\x12*.eolymp.ranker.DeleteScoreboardColumnInput\x1a+.eolymp.ranker.DeleteScoreboardColumnOutput\"f\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x32*0/scoreboards/{scoreboard_id}/columns/{column_id}\x12\xde\x01\n\x18\x44\x65scribeScoreboardColumn\x12,.eolymp.ranker.DescribeScoreboardColumnInput\x1a-.eolymp.ranker.DescribeScoreboardColumnOutput\"e\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x32\x12\x30/scoreboards/{scoreboard_id}/columns/{column_id}\x12\xc9\x01\n\x15ListScoreboardColumns\x12).eolymp.ranker.ListScoreboardColumnsInput\x1a*.eolymp.ranker.ListScoreboardColumnsOutput\"Y\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02&\x12$/scoreboards/{scoreboard_id}/columns\x12\xb3\x01\n\x0eListActivities\x12\".eolymp.ranker.ListActivitiesInput\x1a#.eolymp.ranker.ListActivitiesOutput\"X\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02)\x12\'/scoreboards/{scoreboard_id}/activities\x1a\x06\xb2\xe3\n\x02\x08\x01\x42/Z-github.com/eolymp/go-sdk/eolymp/ranker;rankerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.ranker.ranker_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/ranker;ranker'
  _RANKER._options = None
  _RANKER._serialized_options = b'\262\343\n\002\010\001'
  _RANKER.methods_by_name['CreateScoreboard']._options = None
  _RANKER.methods_by_name['CreateScoreboard']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\016\"\014/scoreboards'
  _RANKER.methods_by_name['UpdateScoreboard']._options = None
  _RANKER.methods_by_name['UpdateScoreboard']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036\032\034/scoreboards/{scoreboard_id}'
  _RANKER.methods_by_name['RebuildScoreboard']._options = None
  _RANKER.methods_by_name['RebuildScoreboard']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002&\"$/scoreboards/{scoreboard_id}/rebuild'
  _RANKER.methods_by_name['DeleteScoreboard']._options = None
  _RANKER.methods_by_name['DeleteScoreboard']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\036*\034/scoreboards/{scoreboard_id}'
  _RANKER.methods_by_name['DescribeScoreboard']._options = None
  _RANKER.methods_by_name['DescribeScoreboard']._serialized_options = b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\036\022\034/scoreboards/{scoreboard_id}'
  _RANKER.methods_by_name['ListScoreboards']._options = None
  _RANKER.methods_by_name['ListScoreboards']._serialized_options = b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\016\022\014/scoreboards'
  _RANKER.methods_by_name['DescribeScoreboardRow']._options = None
  _RANKER.methods_by_name['DescribeScoreboardRow']._serialized_options = b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002/\022-/scoreboards/{scoreboard_id}/rows/{member_id}'
  _RANKER.methods_by_name['ListScoreboardRows']._options = None
  _RANKER.methods_by_name['ListScoreboardRows']._serialized_options = b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002#\022!/scoreboards/{scoreboard_id}/rows'
  _RANKER.methods_by_name['AddScoreboardColumn']._options = None
  _RANKER.methods_by_name['AddScoreboardColumn']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002&\"$/scoreboards/{scoreboard_id}/columns'
  _RANKER.methods_by_name['DeleteScoreboardColumn']._options = None
  _RANKER.methods_by_name['DeleteScoreboardColumn']._serialized_options = b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\0022*0/scoreboards/{scoreboard_id}/columns/{column_id}'
  _RANKER.methods_by_name['DescribeScoreboardColumn']._options = None
  _RANKER.methods_by_name['DescribeScoreboardColumn']._serialized_options = b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\0022\0220/scoreboards/{scoreboard_id}/columns/{column_id}'
  _RANKER.methods_by_name['ListScoreboardColumns']._options = None
  _RANKER.methods_by_name['ListScoreboardColumns']._serialized_options = b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002&\022$/scoreboards/{scoreboard_id}/columns'
  _RANKER.methods_by_name['ListActivities']._options = None
  _RANKER.methods_by_name['ListActivities']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002)\022\'/scoreboards/{scoreboard_id}/activities'
  _CREATESCOREBOARDINPUT._serialized_start=275
  _CREATESCOREBOARDINPUT._serialized_end=345
  _CREATESCOREBOARDOUTPUT._serialized_start=347
  _CREATESCOREBOARDOUTPUT._serialized_end=394
  _UPDATESCOREBOARDINPUT._serialized_start=396
  _UPDATESCOREBOARDINPUT._serialized_end=489
  _UPDATESCOREBOARDOUTPUT._serialized_start=491
  _UPDATESCOREBOARDOUTPUT._serialized_end=515
  _REBUILDSCOREBOARDINPUT._serialized_start=517
  _REBUILDSCOREBOARDINPUT._serialized_end=564
  _REBUILDSCOREBOARDOUTPUT._serialized_start=566
  _REBUILDSCOREBOARDOUTPUT._serialized_end=612
  _DELETESCOREBOARDINPUT._serialized_start=614
  _DELETESCOREBOARDINPUT._serialized_end=660
  _DELETESCOREBOARDOUTPUT._serialized_start=662
  _DELETESCOREBOARDOUTPUT._serialized_end=686
  _DESCRIBESCOREBOARDINPUT._serialized_start=688
  _DESCRIBESCOREBOARDINPUT._serialized_end=760
  _DESCRIBESCOREBOARDOUTPUT._serialized_start=762
  _DESCRIBESCOREBOARDOUTPUT._serialized_end=835
  _LISTSCOREBOARDSINPUT._serialized_start=838
  _LISTSCOREBOARDSINPUT._serialized_end=1005
  _LISTSCOREBOARDSINPUT_FILTER._serialized_start=953
  _LISTSCOREBOARDSINPUT_FILTER._serialized_end=1005
  _LISTSCOREBOARDSOUTPUT._serialized_start=1007
  _LISTSCOREBOARDSOUTPUT._serialized_end=1087
  _DESCRIBESCOREBOARDROWINPUT._serialized_start=1089
  _DESCRIBESCOREBOARDROWINPUT._serialized_end=1159
  _DESCRIBESCOREBOARDROWOUTPUT._serialized_start=1161
  _DESCRIBESCOREBOARDROWOUTPUT._serialized_end=1234
  _LISTSCOREBOARDROWSINPUT._serialized_start=1237
  _LISTSCOREBOARDROWSINPUT._serialized_end=1440
  _LISTSCOREBOARDROWSINPUT_FILTER._serialized_start=1381
  _LISTSCOREBOARDROWSINPUT_FILTER._serialized_end=1440
  _LISTSCOREBOARDROWSOUTPUT._serialized_start=1442
  _LISTSCOREBOARDROWSOUTPUT._serialized_end=1529
  _ADDSCOREBOARDCOLUMNINPUT._serialized_start=1531
  _ADDSCOREBOARDCOLUMNINPUT._serialized_end=1630
  _ADDSCOREBOARDCOLUMNOUTPUT._serialized_start=1632
  _ADDSCOREBOARDCOLUMNOUTPUT._serialized_end=1678
  _DELETESCOREBOARDCOLUMNINPUT._serialized_start=1680
  _DELETESCOREBOARDCOLUMNINPUT._serialized_end=1751
  _DELETESCOREBOARDCOLUMNOUTPUT._serialized_start=1753
  _DELETESCOREBOARDCOLUMNOUTPUT._serialized_end=1783
  _DESCRIBESCOREBOARDCOLUMNINPUT._serialized_start=1785
  _DESCRIBESCOREBOARDCOLUMNINPUT._serialized_end=1858
  _DESCRIBESCOREBOARDCOLUMNOUTPUT._serialized_start=1860
  _DESCRIBESCOREBOARDCOLUMNOUTPUT._serialized_end=1942
  _LISTSCOREBOARDCOLUMNSINPUT._serialized_start=1944
  _LISTSCOREBOARDCOLUMNSINPUT._serialized_end=1995
  _LISTSCOREBOARDCOLUMNSOUTPUT._serialized_start=1997
  _LISTSCOREBOARDCOLUMNSOUTPUT._serialized_end=2090
  _LISTACTIVITIESINPUT._serialized_start=2092
  _LISTACTIVITIESINPUT._serialized_end=2166
  _LISTACTIVITIESOUTPUT._serialized_start=2168
  _LISTACTIVITIESOUTPUT._serialized_end=2245
  _RANKER._serialized_start=2248
  _RANKER._serialized_end=4771
# @@protoc_insertion_point(module_scope)
