# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/annotations/resource.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/annotations/resource.proto\x12\neolymp.api\x1a google/protobuf/descriptor.proto\"@\n\x08Resource\x12\x12\n\x08id_field\x18\xb9\xac\x01 \x01(\t\x12\x0e\n\x04type\x18\xb7\xac\x01 \x01(\t\x12\x10\n\x06parent\x18\xb8\xac\x01 \x01(\t:I\n\x08resource\x12\x1f.google.protobuf.MessageOptions\x18\xb6\xac\x01 \x01(\x0b\x32\x14.eolymp.api.ResourceB9Z7github.com/eolymp/go-sdk/eolymp/annotations;annotationsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.annotations.resource_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(resource)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/eolymp/go-sdk/eolymp/annotations;annotations'
  _RESOURCE._serialized_start=83
  _RESOURCE._serialized_end=147
# @@protoc_insertion_point(module_scope)
